{% extends 'articles/base.html' %}
{% load i18n %}

{% block title %}{% trans 'Articles Tagged' %}: {{ tag.name }}{% endblock %}
{% block extra-head %}
{{ block.super }}
<link rel="alternate" type="application/rss+xml" title="Blog Articles Tagged '{{ tag.name }}' RSS Feed" href="{% url articles_feed tag.rss_name %}" />
{% endblock %}

{% block articles-content %}
<h2>{% trans 'Articles Tagged' %} <em>{{ tag.name }}</em>{% ifnotequal paginator.num_pages 1 %}, {% trans 'page' %} {{ page_obj.number }}{% endifnotequal %}</h2>

{% for article in page_obj.object_list %}
{% include 'articles/_articles.html' %}
{% endfor %}
{% endblock %}
