{% if disqus_forum %}
<div id="disqus_thread"></div>
<script type="text/javascript">
var disqus_identifier = {{ article.id }};
</script>
<script type="text/javascript" src="http://disqus.com/forums/{{ disqus_forum }}/embed.js"></script>
<noscript><a href="http://disqus.com/forums/{{ disqus_forum }}/?url=ref">View the discussion thread.</a></noscript>
<a href="http://disqus.com" class="dsq-brlink">Comments powered by <span class="logo-disqus">Disqus</span></a>
{% endif %}

