{% extends 'articles/base.html' %}
{% load i18n %}

{% block title %}{% trans 'Articles By Author' %}: {{ author.get_name }}{% endblock %}

{% block articles-content %}
<h2>{% trans 'Articles By' %} {{ author.get_name }}{% ifnotequal paginator.num_pages 1 %}, {% trans 'page' %} {{ page_obj.number }}{% endifnotequal %}</h2>

{% for article in page_obj.object_list %}
{% include 'articles/_articles.html' %}
{% endfor %}
{% endblock %}